@@ -78,7 +78,7 @@ Control *get_control_list(int hdevice, int *num_ctrls)
     int currentctrl = 0;
     queryctrl.id = 0 | V4L2_CTRL_FLAG_NEXT_CTRL;
     
-    if ((ret=query_ioctl (hdevice, currentctrl, &queryctrl)) == 0)
+    if ((ret=query_ioctl (hdevice, currentctrl, &queryctrl)) == 0) 
     {
         // The driver supports the V4L2_CTRL_FLAG_NEXT_CTRL flag
         queryctrl.id = 0;
@@ -93,12 +93,16 @@ Control *get_control_list(int hdevice, int *num_ctrls)
             if(ret && queryctrl.id <= currentctrl) 
             {
                 printf("buggy V4L2_CTRL_FLAG_NEXT_CTRL flag implementation (workaround enabled)\n");
+                // increment the control id manually
                 currentctrl++;
+                queryctrl.id = currentctrl;
                 goto next_control;
             }
-            else if (!ret && queryctrl.id == currentctrl)
+            else if ((queryctrl.id == V4L2_CTRL_FLAG_NEXT_CTRL) || (!ret && queryctrl.id == currentctrl))
             {
-                printf("buggy V4L2_CTRL_FLAG_NEXT_CTRL flag implementation (failed enumeration)\n");
+                printf("buggy V4L2_CTRL_FLAG_NEXT_CTRL flag implementation (failed enumeration for id=0x%08x)\n", 
+                    queryctrl.id);
+                // stop control enumeration
                 *num_ctrls = n;
                 return first;
             }
@@ -620,6 +624,8 @@ static void update_widget_state(Control *control_list, void *all_data)
  
 void create_control_widgets(Control *control_list, void *all_data, int control_only, int verbose)
 {  
+    struct ALL_DATA *data = (struct ALL_DATA *) all_data;
+    struct vdIn *videoIn = data->videoIn;
     Control *current = control_list;
     Control *next = current->next;
     int done = 0;
@@ -813,6 +819,8 @@ void create_control_widgets(Control *control_list, void *all_data, int control_o
 			            
 			            g_signal_connect (GTK_COMBO_BOX (current->spinbutton), "changed",
 				            G_CALLBACK (pix_ord_changed), all_data);
+				        
+				        videoIn->isbayer = (current->value ? TRUE : FALSE);
                     }
                 
                     current->widget = gtk_check_button_new();
